@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2009 Index Data
+ * Copyright (C) 1995-2010 Index Data
  * See the file LICENSE for details.
  */
 /**
@@ -8,172 +8,36 @@
  */
 
 #include <stdlib.h>
+#include <assert.h>
 #include <yaz/srw.h>
 #include <yaz/matchstr.h>
 #include <yaz/yaz-iconv.h>
 
-static int hex_digit (int ch)
+/** \brief decodes HTTP path (which should hold SRU database)
+    \param n memory for returned result
+    \param uri URI path (up to but not including ?)
+    \param len URI len (up to but not including ?)
+    \returns ODR allocated database
+*/
+static char *yaz_decode_sru_dbpath_odr(ODR n, const char *uri, size_t len)
 {
-    if (ch >= '0' && ch <= '9')
-        return ch - '0';
-    else if (ch >= 'a' && ch <= 'f')
-        return ch - 'a'+10;
-    else if (ch >= 'A' && ch <= 'F')
-        return ch - 'A'+10;
-    return 0;
+    char *ret = odr_malloc(n, strlen(uri) + 1);
+    yaz_decode_uri_component(ret, uri, len);
+    return ret;
 }
 
-void encode_uri_char(char *dst, char ch)
+void yaz_encode_sru_dbpath_buf(char *dst, const char *db)
 {
-    if (ch == ' ')
-        strcpy(dst, "+");
-    /*  mark        = "-" | "_" | "." | "!" | "~" | "*" | "'" | "(" | ")" */
-    else if ((ch >= 'A' && ch <= 'Z') || (ch >= 'a' && ch <= 'z') ||
-             (ch >= '0' && ch <= '9') || strchr("-_.!~*'(|)", ch))
-    {
-        dst[0] = ch;
-        dst[1] = '\0';
-    }
-    else
-    {
-        dst[0] = '%';
-        sprintf(dst+1, "%02X", (unsigned char ) ch);
-    }
+    assert(db);
+    *dst = '/';
+    yaz_encode_uri_component(dst+1, db);
 }
 
-static void yaz_array_to_uri(char **path, ODR o, char **name, char **value)
+char *yaz_encode_sru_dbpath_odr(ODR out, const char *db)
 {
-    size_t i, szp = 0, sz = 1;
-    for(i = 0; name[i]; i++)
-        sz += strlen(name[i]) + 3 + strlen(value[i]) * 3;
-    *path = (char *) odr_malloc(o, sz);
-    
-    for(i = 0; name[i]; i++)
-    {
-        size_t j, ilen;
-        if (i)
-            (*path)[szp++] = '&';
-        ilen = strlen(name[i]);
-        memcpy(*path+szp, name[i], ilen);
-        szp += ilen;
-        (*path)[szp++] = '=';
-        for (j = 0; value[i][j]; j++)
-        {
-            size_t vlen;
-            char vstr[5];
-            encode_uri_char(vstr, value[i][j]);
-            vlen = strlen(vstr);
-            memcpy(*path+szp, vstr, vlen);
-            szp += vlen;
-        }
-    }
-    (*path)[szp] = '\0';
-}
-
-int yaz_uri_to_array(const char *path, ODR o, char ***name, char ***val)
-{
-    int no = 2;
-    const char *cp;
-    *name = 0;
-    if (*path == '?')
-        path++;
-    if (!*path)
-        return 0;
-    cp = path;
-    while ((cp = strchr(cp, '&')))
-    {
-        cp++;
-        no++;
-    }
-    *name = (char **) odr_malloc(o, no * sizeof(char*));
-    *val = (char **) odr_malloc(o, no * sizeof(char*));
-
-    for (no = 0; *path; no++)
-    {
-        const char *p1 = strchr(path, '=');
-        size_t i = 0;
-        char *ret;
-        if (!p1)
-            break;
-
-        (*name)[no] = (char *) odr_malloc(o, (p1-path)+1);
-        memcpy((*name)[no], path, p1-path);
-        (*name)[no][p1-path] = '\0';
-
-        path = p1 + 1;
-        p1 = strchr(path, '&');
-        if (!p1)
-            p1 = strlen(path) + path;
-        (*val)[no] = ret = (char *) odr_malloc(o, p1 - path + 1);
-        while (*path && *path != '&')
-        {
-            if (*path == '+')
-            {
-                ret[i++] = ' ';
-                path++;
-            }
-            else if (*path == '%' && path[1] && path[2])
-            {
-                ret[i++] = hex_digit (path[1])*16 + hex_digit (path[2]);
-                path = path + 3;
-            }
-            else
-                ret[i++] = *path++;
-        }
-        ret[i] = '\0';
-
-        if (*path)
-            path++;
-    }
-    (*name)[no] = 0;
-    (*val)[no] = 0;
-    return no;
-}
-
-char *yaz_uri_val(const char *path, const char *name, ODR o)
-{
-    size_t nlen = strlen(name);
-    if (*path != '?')
-        return 0;
-    path++;
-    while (path && *path)
-    {
-        const char *p1 = strchr(path, '=');
-        if (!p1)
-            break;
-        if ((size_t)(p1 - path) == nlen && !memcmp(path, name, nlen))
-        {
-            size_t i = 0;
-            char *ret;
-            
-            path = p1 + 1;
-            p1 = strchr(path, '&');
-            if (!p1)
-                p1 = strlen(path) + path;
-            ret = (char *) odr_malloc(o, p1 - path + 1);
-            while (*path && *path != '&')
-            {
-                if (*path == '+')
-                {
-                    ret[i++] = ' ';
-                    path++;
-                }
-                else if (*path == '%' && path[1] && path[2])
-                {
-                    ret[i++] = hex_digit (path[1])*16 + hex_digit (path[2]);
-                    path = path + 3;
-                }
-                else
-                    ret[i++] = *path++;
-            }
-            ret[i] = '\0';
-            return ret;
-        }
-        path = strchr(p1, '&');
-        if (path)
-            path++;
-    }
-    return 0;
+    char *dst = odr_malloc(out, 3 * strlen(db) + 2);
+    yaz_encode_sru_dbpath_buf(dst, db);
+    return dst;
 }
 
 #if YAZ_HAVE_XML2
@@ -422,12 +286,7 @@ int yaz_srw_decode(Z_HTTP_Request *hreq, Z_SRW_PDU **srw_pdu,
             if (!p1)
                 p1 = p0 + strlen(p0);
             if (p1 != p0)
-            {
-                db = (char*) odr_malloc(decode, p1 - p0 + 1);
-                memcpy (db, p0, p1 - p0);
-                db[p1 - p0] = '\0';
-            }
-
+                db = yaz_decode_sru_dbpath_odr(decode, p0, p1 - p0);
             grab_charset(decode, content_type, charset);
 
             ret = z_soap_codec(decode, soap_package, 
@@ -550,11 +409,7 @@ int yaz_sru_decode(Z_HTTP_Request *hreq, Z_SRW_PDU **srw_pdu,
         if (!p1)
             p1 = p0 + strlen(p0);
         if (p1 != p0)
-        {
-            db = (char*) odr_malloc(decode, p1 - p0 + 1);
-            memcpy (db, p0, p1 - p0);
-            db[p1 - p0] = '\0';
-        }
+            db = yaz_decode_sru_dbpath_odr(decode, p0, p1 - p0);
         if (!strcmp(hreq->method, "POST"))
             p1 = hreq->content_buf;
         yaz_uri_to_array(p1, decode, &uri_name, &uri_val);
@@ -1469,7 +1324,6 @@ void yaz_encode_sru_extra(Z_SRW_PDU *sr, ODR odr, const char *extra_args)
 }
 
 
-
 /*
  * Local variables:
  * c-basic-offset: 4
