@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2009 Index Data.
+ * Copyright (C) 1995-2010 Index Data.
  * All rights reserved.
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -130,7 +130,7 @@ struct ZOOM_resultset_p {
     Z_SortKeySpecList *r_sort_spec;
     ZOOM_query query;
     int refcount;
-    int size;
+    Odr_int size;
     int step;
     int piggyback;
     char *setname;
@@ -146,12 +146,15 @@ struct ZOOM_resultset_p {
 
 struct ZOOM_record_p {
     ODR odr;
-    WRBUF wrbuf_marc;
-    WRBUF wrbuf_iconv;
-    WRBUF wrbuf_opac;
+    WRBUF wrbuf;
     Z_NamePlusRecord *npr;
     const char *schema;
 
+#if YAZ_HAVE_XML2
+    xmlChar *xml_mem;
+    int xml_size;
+#endif
+
     const char *diag_uri;
     const char *diag_message;
     const char *diag_details;
