@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2009 Index Data
+ * Copyright (C) 1995-2010 Index Data
  * See the file LICENSE for details.
  */
 #include <yaz/record_conv.h>
@@ -7,7 +7,6 @@
 #include <yaz/wrbuf.h>
 #include <string.h>
 #include <yaz/log.h>
-#include <yaz/libxml2_error.h>
 
 #if HAVE_CONFIG_H
 #include <config.h>
@@ -334,7 +333,7 @@ static void tst_convert2(void)
 int main(int argc, char **argv)
 {
     YAZ_CHECK_INIT(argc, argv);
-    libxml2_error_to_yazlog(0 /* disable log */, 0);
+    yaz_log_xml_errors(0, 0 /* disable log */);
 #if YAZ_HAVE_XML2
     tst_configure();
 #endif
