@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2008 Index Data
+ * Copyright (C) 1995-2010 Index Data
  * See the file LICENSE for details.
  */
 #include <yaz/retrieval.h>
@@ -7,7 +7,6 @@
 #include <yaz/wrbuf.h>
 #include <string.h>
 #include <yaz/log.h>
-#include <yaz/libxml2_error.h>
 
 #if HAVE_CONFIG_H
 #include <config.h>
@@ -316,7 +315,7 @@ int main(int argc, char **argv)
 {
     YAZ_CHECK_INIT(argc, argv);
 
-    libxml2_error_to_yazlog(0 /* disable it */, "");
+    yaz_log_xml_errors(0, 0 /* disable it */);
 
 #if YAZ_HAVE_XSLT
     tst_configure();
@@ -327,6 +326,7 @@ int main(int argc, char **argv)
 /*
  * Local variables:
  * c-basic-offset: 4
+ * c-file-style: "Stroustrup"
  * indent-tabs-mode: nil
  * End:
  * vim: shiftwidth=4 tabstop=8 expandtab
