@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2009 Index Data
+ * Copyright (C) 1995-2010 Index Data
  * See the file LICENSE for details.
  */
 
@@ -12,10 +12,13 @@
 static void tstwrbuf(void)
 {
     int step;
-    WRBUF wr = wrbuf_alloc();
+    WRBUF wr;
 
+    wr = 0;
+    wrbuf_destroy(wr);
+
+    wr = wrbuf_alloc();
     YAZ_CHECK(wr);
-
     wrbuf_destroy(wr);
 
     wr = wrbuf_alloc();
