@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2009 Index Data
+ * Copyright (C) 1995-2010 Index Data
  * See the file LICENSE for details.
  */
 
@@ -11,8 +11,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
-
-#include <yaz/comstack.h>
+#include <yaz/wrbuf.h>
 
 #if HAVE_READLINE_READLINE_H
 #include <readline/readline.h> 
@@ -21,10 +20,7 @@
 #include <readline/history.h>
 #endif
 
-#include <yaz/xmalloc.h>
-
 #include <yaz/log.h>
-#include <yaz/nmem.h>
 #include <yaz/zoom.h>
 
 #define MAX_CON 100
@@ -62,20 +58,17 @@ static int next_token(const char **cpp, const char **t_start)
     return len;  /* return -1 if no token was read .. */
 }
 
-static int next_token_copy(const char **cpp, char *buf_out, int buf_max)
+static WRBUF next_token_new_wrbuf(const char **cpp)
 {
+    WRBUF w = 0;
     const char *start;
     int len = next_token(cpp, &start);
     if (len < 0)
-    {
-        *buf_out = 0;
-        return len;
-    }
-    if (len >= buf_max)
-        len = buf_max-1;
-    memcpy(buf_out, start, len);
-    buf_out[len] = '\0';
-    return len;
+        return 0;
+    w = wrbuf_alloc();
+    if (len > 0)
+        wrbuf_write(w, start, len);
+    return w;
 }
 
 static int is_command(const char *cmd_str, const char *this_str, int this_len)
@@ -92,32 +85,37 @@ static void cmd_set(ZOOM_connection *c, ZOOM_resultset *r,
                     ZOOM_options options,
                     const char **args)
 {
-    char key[40], val[80];
+    WRBUF key, val;
 
-    if (next_token_copy(args, key, sizeof(key)) < 0)
+    if (!(key = next_token_new_wrbuf(args)))
     {
         printf("missing argument for set\n");
         return ;
     }
-    if (next_token_copy(args, val, sizeof(val)) < 0)
-        ZOOM_options_set(options, key, 0);
+    if ((val = next_token_new_wrbuf(args)))
+    {
+        ZOOM_options_set(options, wrbuf_cstr(key), wrbuf_cstr(val));
+        wrbuf_destroy(val);
+    }
     else
-        ZOOM_options_set(options, key, val);
+        ZOOM_options_set(options, wrbuf_cstr(key), 0);
+    wrbuf_destroy(key);
 }
 
 static void cmd_get(ZOOM_connection *c, ZOOM_resultset *r,
                     ZOOM_options options,
                     const char **args)
 {
-    char key[40];
-    if (next_token_copy(args, key, sizeof(key)) < 0)
+    WRBUF key;
+    if (!(key = next_token_new_wrbuf(args)))
     {
         printf("missing argument for get\n");
     }
     else
     {
-        const char *val = ZOOM_options_get(options, key);
-        printf("%s = %s\n", key, val ? val : "<null>");
+        const char *val = ZOOM_options_get(options, wrbuf_cstr(key));
+        printf("%s = %s\n", wrbuf_cstr(key), val ? val : "<null>");
+        wrbuf_destroy(key);
     }
 }
 
@@ -125,8 +123,8 @@ static void cmd_rget(ZOOM_connection *c, ZOOM_resultset *r,
                      ZOOM_options options,
                      const char **args)
 {
-    char key[40];
-    if (next_token_copy(args, key, sizeof(key)) < 0)
+    WRBUF key;
+    if (!(key = next_token_new_wrbuf(args)))
     {
         printf("missing argument for get\n");
     }
@@ -139,9 +137,10 @@ static void cmd_rget(ZOOM_connection *c, ZOOM_resultset *r,
             if (!r[i])
                 continue;
             
-            val = ZOOM_resultset_option_get(r[i], key);
-            printf("%s = %s\n", key, val ? val : "<null>");
+            val = ZOOM_resultset_option_get(r[i], wrbuf_cstr(key));
+            printf("%s = %s\n", wrbuf_cstr(key), val ? val : "<null>");
         }
+        wrbuf_destroy(key);
     }
 }
 
@@ -149,36 +148,38 @@ static void cmd_close(ZOOM_connection *c, ZOOM_resultset *r,
                       ZOOM_options options,
                       const char **args)
 {
-    char host[60];
+    WRBUF host;
     int i;
-    next_token_copy(args, host, sizeof(host));
+    host = next_token_new_wrbuf(args);
     for (i = 0; i<MAX_CON; i++)
     {
         const char *h;
         if (!c[i])
             continue;
-        if ((h = ZOOM_connection_option_get(c[i], "host"))
-            && !strcmp(h, host))
+        if (!host)
         {
             ZOOM_connection_destroy(c[i]);
             c[i] = 0;
         }
-        else if (*host == '\0')
+        else if ((h = ZOOM_connection_option_get(c[i], "host"))
+                 && !strcmp(h, wrbuf_cstr(host)))
         {
             ZOOM_connection_destroy(c[i]);
             c[i] = 0;
         }
     }
+    if (host)
+        wrbuf_destroy(host);
 }
 
 static void display_records(ZOOM_connection c,
                             ZOOM_resultset r,
-                            int start, int count)
+                            size_t start, size_t count, const char *type)
 {
-    int i;
-    for (i = 0; i<count; i++)
+    size_t i;
+    for (i = 0; i < count; i++)
     {
-        int pos = i + start;
+        size_t pos = i + start;
         ZOOM_record rec = ZOOM_resultset_record(r, pos);
         const char *db = ZOOM_record_get(rec, "database", 0);
         
@@ -189,21 +190,22 @@ static void display_records(ZOOM_connection c,
             const char *diagset;
             int error = ZOOM_record_error(rec, &msg, &addinfo, &diagset);
             
-            printf("%d %s: %s (%s:%d) %s\n", pos, (db ? db : "unknown"),
+            printf("%lld %s: %s (%s:%d) %s\n", (long long) pos,
+                   (db ? db : "unknown"),
                    msg, diagset, error, addinfo ? addinfo : "none");
         }
         else
         {
             int len, opac_len;
-            const char *render = ZOOM_record_get(rec, "render", &len);
+            const char *render = ZOOM_record_get(rec, type, &len);
             const char *opac_render = ZOOM_record_get(rec, "opac", &opac_len);
             const char *syntax = ZOOM_record_get(rec, "syntax", 0);
             const char *schema = ZOOM_record_get(rec, "schema", 0);
             /* if rec is non-null, we got a record for display */
             if (rec)
             {
-                printf("%d database=%s syntax=%s schema=%s\n",
-                       pos, (db ? db : "unknown"), syntax,
+                printf("%lld database=%s syntax=%s schema=%s\n",
+                       (long long) pos, (db ? db : "unknown"), syntax,
                        schema ? schema : "unknown");
                 if (render)
                 {
@@ -229,20 +231,35 @@ static void cmd_show(ZOOM_connection *c, ZOOM_resultset *r,
                      const char **args)
 {
     int i;
-    char start_str[10], count_str[10];
+    size_t start = 0, count = 1;
+    const char *type = "render";
+    WRBUF render_str = 0;
 
-    if (next_token_copy(args, start_str, sizeof(start_str)) >= 0)
-        ZOOM_options_set(options, "start", start_str);
+    {
+        WRBUF tmp;
 
-    if (next_token_copy(args, count_str, sizeof(count_str)) >= 0)
-        ZOOM_options_set(options, "count", count_str);
+        if ((tmp = next_token_new_wrbuf(args)))
+        {
+            start = atoi(wrbuf_cstr(tmp));
+            wrbuf_destroy(tmp);
+        }
 
-    for (i = 0; i<MAX_CON; i++)
-        ZOOM_resultset_records(r[i], 0, atoi(start_str), atoi(count_str));
+        if ((tmp = next_token_new_wrbuf(args)))
+        {
+            count = atoi(wrbuf_cstr(tmp));
+            wrbuf_destroy(tmp);
+        }
+        render_str = next_token_new_wrbuf(args);
+    }
+    if (render_str)
+        type = wrbuf_cstr(render_str);
+
+    for (i = 0; i < MAX_CON; i++)
+        ZOOM_resultset_records(r[i], 0, start, count);
     while (ZOOM_event(MAX_CON, c))
         ;
 
-    for (i = 0; i<MAX_CON; i++)
+    for (i = 0; i < MAX_CON; i++)
     {
         int error;
         const char *errmsg, *addinfo, *dset;
@@ -256,13 +273,12 @@ static void cmd_show(ZOOM_connection *c, ZOOM_resultset *r,
         else if (r[i])
         {
             /* OK, no major errors. Display records... */
-            int start = ZOOM_options_get_int(options, "start", 0);
-            int count = ZOOM_options_get_int(options, "count", 0);
-            display_records(c[i], r[i], start, count);
+            display_records(c[i], r[i], start, count, type);
         }
     }
-    ZOOM_options_set(options, "count", "0");
-    ZOOM_options_set(options, "start", "0");
+    if (render_str)
+        wrbuf_destroy(render_str);
+       
 }
 
 static void cmd_ext(ZOOM_connection *c, ZOOM_resultset *r,
@@ -270,19 +286,15 @@ static void cmd_ext(ZOOM_connection *c, ZOOM_resultset *r,
                     const char **args)
 {
     ZOOM_package p[MAX_CON];
-    char ext_type_str[10];
-    
     int i;
-
-    if (next_token_copy(args, ext_type_str, sizeof(ext_type_str)) < 0)
-        return;
+    WRBUF ext_type_str = next_token_new_wrbuf(args);
     
     for (i = 0; i<MAX_CON; i++)
     {
         if (c[i])
         {
             p[i] = ZOOM_connection_package(c[i], 0);
-            ZOOM_package_send(p[i], ext_type_str);
+            ZOOM_package_send(p[i], ext_type_str ? wrbuf_cstr(ext_type_str):0);
         }
         else
             p[i] = 0;
@@ -315,6 +327,8 @@ static void cmd_ext(ZOOM_connection *c, ZOOM_resultset *r,
         }
         ZOOM_package_destroy(p[i]);
     }
+    if (ext_type_str)
+        wrbuf_destroy(ext_type_str);
 }
 
 static void cmd_debug(ZOOM_connection *c, ZOOM_resultset *r,
@@ -377,10 +391,10 @@ static void cmd_search(ZOOM_connection *c, ZOOM_resultset *r,
             int start = ZOOM_options_get_int(options, "start", 0);
             int count = ZOOM_options_get_int(options, "count", 0);
 
-            printf("%s: %ld hits\n", ZOOM_connection_option_get(c[i], "host"),
-                   (long) ZOOM_resultset_size(r[i]));
+            printf("%s: %lld hits\n", ZOOM_connection_option_get(c[i], "host"),
+                   (long long int) ZOOM_resultset_size(r[i]));
             /* and display */
-            display_records(c[i], r[i], start, count);
+            display_records(c[i], r[i], start, count, "render");
         }
     }
 }
@@ -434,12 +448,11 @@ static void cmd_scan(ZOOM_connection *c, ZOOM_resultset *r,
             size_t p, sz = ZOOM_scanset_size(s[i]);
             for (p = 0; p < sz; p++)
             {
-                int occ = 0;
-                int len = 0;
+                size_t occ = 0;
+                size_t len = 0;
                 const char *term = ZOOM_scanset_display_term(s[i], p,
                                                              &occ, &len);
-                
-                printf("%.*s %d\n", len, term, occ);
+                printf("%.*s %lld\n", (int) len, term, (long long int) occ);
             }            
             ZOOM_scanset_destroy(s[i]);
         }
@@ -471,7 +484,7 @@ static void cmd_help(ZOOM_connection *c, ZOOM_resultset *r,
 {
     printf("connect <zurl>\n");
     printf("search <pqf>\n");
-    printf("show [<start> [<count>]\n");
+    printf("show [<start> [<count> [<type]]]\n");
     printf("scan <term>\n");
     printf("quit\n");
     printf("close <zurl>\n");
@@ -496,6 +509,7 @@ static void cmd_help(ZOOM_connection *c, ZOOM_resultset *r,
     printf(" implementationName\n");
     printf(" charset\n");
     printf(" lang\n");
+    printf(" timeout\n");
 }
 
 static void cmd_connect(ZOOM_connection *c, ZOOM_resultset *r,
@@ -504,9 +518,9 @@ static void cmd_connect(ZOOM_connection *c, ZOOM_resultset *r,
 {
     int error;
     const char *errmsg, *addinfo, *dset;
-    char host[60];
     int j, i;
-    if (next_token_copy(args, host, sizeof(host)) < 0)
+    WRBUF host = next_token_new_wrbuf(args);
+    if (!host)
     {
         printf("missing host after connect\n");
         return ;
@@ -515,7 +529,7 @@ static void cmd_connect(ZOOM_connection *c, ZOOM_resultset *r,
     {
         const char *h;
         if (c[i] && (h = ZOOM_connection_option_get(c[i], "host")) &&
-            !strcmp(h, host))
+            !strcmp(h, wrbuf_cstr(host)))
         {
             ZOOM_connection_destroy(c[i]);
             break;
@@ -528,17 +542,19 @@ static void cmd_connect(ZOOM_connection *c, ZOOM_resultset *r,
         if (j == -1)
         {
             printf("no more connection available\n");
+            wrbuf_destroy(host);
             return;
         }
         i = j;   /* OK, use this one is available */
     }
     c[i] = ZOOM_connection_create(options);
-    ZOOM_connection_connect(c[i], host, 0);
+    ZOOM_connection_connect(c[i], wrbuf_cstr(host), 0);
         
     if ((error = ZOOM_connection_error_x(c[i], &errmsg, &addinfo, &dset)))
         printf("%s error: %s (%s:%d) %s\n",
                ZOOM_connection_option_get(c[i], "host"), errmsg,
                dset, error, addinfo);
+    wrbuf_destroy(host);
 }
 
 static int cmd_parse(ZOOM_connection *c, ZOOM_resultset *r,
